==> netbox_disk-0.0.7.6.5.37-py3-none-any.whl: netbox_disk/api/views.py <==
from rest_framework import serializers
from rest_framework.decorators import action
from rest_framework.response import Response
from rest_framework.routers import APIRootView

from netbox.api.viewsets import NetBoxModelViewSet

from netbox_disk.api.serializers import (
    DiskSerializer,
    FilesystemSerializer,
    PhysicalVolumeSerializer
)
from netbox_disk.filters import DiskFilter, FilesystemFilter, PhysicalVolumeFilter
from netbox_disk.models import Disk, Filesystem, PhysicalVolume


class NetboxDiskRootView(APIRootView):
    """
    NetboxDNS API root view
    """

    def get_view_name(self):
        return "NetboxDisk"


class DiskViewSet(NetBoxModelViewSet):
    queryset = Disk.objects.all()
    serializer_class = DiskSerializer
    filterset_class = DiskFilter

    @action(detail=True, methods=["get"])
    def disks(self, request, pk=None):
        disks = Disk.objects.filter(disks__id=pk)
        serializer = DiskSerializer(disks, many=True, context={"request": request})
        return Response(serializer.data)


class FilesystemViewSet(NetBoxModelViewSet):
    queryset = Filesystem.objects.all()
    serializer_class = FilesystemSerializer
    filterset_class = FilesystemFilter

    @action(detail=True, methods=["get"])
    def filesystem(self, request, pk=None):
        filesystem = Filesystem.objects.filter(filesystem__id=pk)
        serializer = FilesystemSerializer(filesystem, many=True, context={"request": request})
        return Response(serializer.data)


class PhysicalVolumeViewSet(NetBoxModelViewSet):
    queryset = PhysicalVolume.objects.all()
    serializer_class = PhysicalVolumeSerializer
    filterset_class = PhysicalVolumeFilter

    @action(detail=True, methods=["get"])
    def physical_volume(self, request, pk=None):
        physical_volume = PhysicalVolume.objects.filter(physical_volume__id=pk)
        serializer = PhysicalVolumeSerializer(physical_volume, many=True, context={"request": request})
        return Response(serializer.data)

==> netbox_disk-0.0.7.6.5.40-py3-none-any.whl: netbox_disk/api/views.py <==
from rest_framework import serializers
from rest_framework.decorators import action
from rest_framework.response import Response
from rest_framework.routers import APIRootView

from netbox.api.viewsets import NetBoxModelViewSet

from netbox_disk.api.serializers import (
    DiskSerializer,
    FilesystemSerializer,
    PhysicalVolumeSerializer
)
from netbox_disk.filters import DiskFilter, FilesystemFilter, PhysicalVolumeFilter
from netbox_disk.models import Disk, Filesystem, PhysicalVolume


class NetboxDiskRootView(APIRootView):
    """
    NetboxDNS API root view
    """

    def get_view_name(self):
        return "NetboxDisk"


class DiskViewSet(NetBoxModelViewSet):
    queryset = Disk.objects.all()
    serializer_class = DiskSerializer
    filterset_class = DiskFilter

    @action(detail=True, methods=["get"])
    def disks(self, request, pk=None):
        disks = Disk.objects.filter(disks__id=pk)
        serializer = DiskSerializer(disks, many=True, context={"request": request})
        return Response(serializer.data)


class FilesystemViewSet(NetBoxModelViewSet):
    queryset = Filesystem.objects.all()
    serializer_class = FilesystemSerializer
    filterset_class = FilesystemFilter

    @action(detail=True, methods=["get"])
    def filesystem(self, request, pk=None):
        filesystem = Filesystem.objects.filter(filesystem__id=pk)
        serializer = FilesystemSerializer(filesystem, many=True, context={"request": request})
        return Response(serializer.data)


class PhysicalVolumeViewSet(NetBoxModelViewSet):
    queryset = PhysicalVolume.objects.all()
    serializer_class = PhysicalVolumeSerializer
    filterset_class = PhysicalVolumeFilter

    @action(detail=True, methods=["get"])
    def physicalvolume(self, request, pk=None):
        physicalvolume = PhysicalVolume.objects.filter(physicalvolume__id=pk)
        serializer = PhysicalVolumeSerializer(physicalvolume, many=True, context={"request": request})
        return Response(serializer.data)
